@@ -25,10 +25,10 @@ public:
 
     explicit ScrollIndicator(ArrowDirection direction);
 
-    Q_REQUIRED_RESULT QRectF boundingRect() const override;
+    [[nodiscard]] QRectF boundingRect() const override;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
 
-    Q_REQUIRED_RESULT ArrowDirection direction() const
+    [[nodiscard]] ArrowDirection direction() const
     {
         return mDirection;
     }
@@ -118,7 +118,7 @@ public:
     using List = QList<MonthGraphicsItem *>;
 
     explicit MonthGraphicsItem(MonthItem *manager);
-    ~MonthGraphicsItem();
+    ~MonthGraphicsItem() override;
 
     /**
       Change QGraphicsItem pos and boundingRect in the scene
@@ -200,4 +200,3 @@ private:
     MonthItem *mMonthItem = nullptr;
 };
 }
-
